@@ -16,10 +16,9 @@ Usage::
     session_client: PersonalizeRuntimeClient = session.client("personalize-runtime")
     ```
 """
-from mypy_boto3_personalize_runtime.client import (
-    PersonalizeRuntimeClient as Client,
-    PersonalizeRuntimeClient,
-)
+from mypy_boto3_personalize_runtime.client import PersonalizeRuntimeClient
+
+Client = PersonalizeRuntimeClient
 
 
 __all__ = ("Client", "PersonalizeRuntimeClient")
